Create individual counters and timers for compilation kinds.

Bug: 112676029
Test: m
Change-Id: I6f500d1253288e89ab83cd5d77f6ce0360bff340
diff --git a/runtime/jit/jit_code_cache.h b/runtime/jit/jit_code_cache.h
index 4340603..d055ed3 100644
--- a/runtime/jit/jit_code_cache.h
+++ b/runtime/jit/jit_code_cache.h
@@ -579,8 +579,11 @@
 
   // ---------------- JIT statistics -------------------------------------- //
 
-  // Number of compilations done throughout the lifetime of the JIT.
-  size_t number_of_compilations_ GUARDED_BY(Locks::jit_lock_);
+  // Number of baseline compilations done throughout the lifetime of the JIT.
+  size_t number_of_baseline_compilations_ GUARDED_BY(Locks::jit_lock_);
+
+  // Number of optimized compilations done throughout the lifetime of the JIT.
+  size_t number_of_optimized_compilations_ GUARDED_BY(Locks::jit_lock_);
 
   // Number of compilations for on-stack-replacement done throughout the lifetime of the JIT.
   size_t number_of_osr_compilations_ GUARDED_BY(Locks::jit_lock_);